#
# spec file for package mirrormagic
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           mirrormagic
Version:        3.3.1
Release:        1.2
Summary:        Puzzle game where you steer a beam of light using mirrors
License:        GPL-2.0-only
Group:          Amusements/Games/Logic
URL:            https://www.artsoft.org/mirrormagic/
Source0:        https://www.artsoft.org/RELEASES/unix/%{name}/%{name}-%{version}-linux.tar.gz
Source1:        %{name}-icons.tar.gz
Source2:        %{name}.desktop
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(SDL2_image)
BuildRequires:  pkgconfig(SDL2_mixer)
BuildRequires:  pkgconfig(SDL2_net)
BuildRequires:  pkgconfig(sdl2)

%description
This is a nice little game with color graphics and sound for your
Unix system with color X11. You need an 8-bit color display or better.
It will not work on black&white systems, and maybe not on gray scale
systems.

It was first released as "Mindbender" in the year 1989 on the Amiga
(with ports on other computer systems) and is in fact a clone of the
C64 game "Deflektor".

%prep
%autosetup -b 1

rm -rfv lib mirrormagic
find . -name "*.orig" -delete

%build
%make_build \
    PROGBASE=%{name} \
    OPTIONS="%{optflags} -fPIE" \
    EXTRA_LDFLAGS="%{optflags} -pie" \
    BASE_PATH=%{_datadir}/%{name}

%install
# install executable
install -Dm 0755 %{name} %{buildroot}%{_bindir}/%{name}

# install directories
mkdir -p %{buildroot}%{_datadir}/%{name}/{graphics,levels,music,sounds}
for d in graphics levels music sounds ; do
    cp -a $d %{buildroot}%{_datadir}/%{name}
done

# install icons
for i in 32 48 64 72 96 ; do
    install -Dm 0644 ../icons/%{name}_${i}x${i}.png \
            %{buildroot}/%{_datadir}/icons/hicolor/${i}x${i}/apps/%{name}.png
done

# install Desktop file
install -Dm 0644 %{SOURCE2} %{buildroot}%{_datadir}/applications/%{name}.desktop

%suse_update_desktop_file %{name}
%fdupes -s %{buildroot}%{_prefix}

%files
%license COPYING
%doc ChangeLog CREDITS
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/%{name}

%changelog
* Sun Jan 28 2024 Dirk Müller <dmueller@suse.com>
- update to version 3.3.1:
  * improved error handling: display error message on screen (not
    only in the error file or on the console), and display path
    of the error file
  * fixed problem with R'n'D restarting with same level set that
    may have caused a problem (and therefore failing again and
    again); after an error, the last level set is now deactivated
    in file "levelsetup.conf" to restart with default level set
    (which should work without error)
  * added scripts directory to distribution package to enable
    building element definitions after editing artwork config
    source code files
  * added volume controls for sounds, loops and music to sound
    setup
* Fri Jul 14 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to version 3.3.0
  * added new Deflektor style steel slope game elements
  * added new Deflektor style fixed mirror game elements
  * added flipping and rotating brushes in level editor using keys “x”, “y” and “z”
  * fixed several bugs
- Update to version 3.2.0
  * improved graphics engine to support more custom graphics definitions
  * added animations for the bomb and mine game elements in active state
  * added customizability of content for the gray ball game element
  * added new text envelope game elements to show messages in the game
  * fixed a lot of bugs and problems in the game and graphics engine
- compressed icons to save space
* Thu Jan 26 2023 Carsten Ziepke <kieltux@gmail.com>
- Update to version 3.1.0
  * High score server support – see all your scores and those of
    others
  * Multiple player names – separate scores and progress for each
    familiy member
  * Improved graphics with Amiga-style color-cycling graphic
    animations
  * Includes original title screen and title music
  * Includes original title story from 1989, accessible from
    main menu
- Changed RO_GAME_DIR to BASE_PATH
- RW_GAME_DIR is no longer used. Games scores are now written to
  ~/.mirrormagic in user homedir.
- Drop fix-multiple-definitions.patch and reproducible.patch,
  both fixed upstream
- Run spec-cleaner
* Sun Sep 25 2022 Bernhard Wiedemann <bwiedemann@suse.com>
- Add reproducible.patch to better declare dependencies
  to avoid non-determinism from parallel builds
* Thu Apr 29 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to 3.0.0
  * Build with SDL2
  * Integrated the classic Mirror Magic game engine into the game
    Rocks’n’Diamonds as a new custom game engine
  * Mirror Magic now also offers new features already known from
    R’n’D like scalable window size and fullscreen mode and
    solution tapes were added to the included level sets
    “Deflektor” and “Mindbender”.
- Add fix-multiple-definitions.patch
- Drop upstream fixed mirrormagic-2.0.2-src_tools.c.patch,
  mirrormagic-2.0.2-src_editor.c.patch,
  mirrormagic-2.0.2-src_events.c.patch,
  mirrormagic-2.0.2-src_files.c.patch,
  mirrormagic-2.0.2-src_libgame_sdl.c.patch,
  mirrormagic-2.0.2-src_libgame_sdl.h.patch,
  mirrormagic-2.0.2-src_libgame_gadgets.c.patch and
  mirrormagic-2.0.2-src_main.h.patch
* Mon May  8 2017 rpm@fthiessen.de
- Fixed user and group for Factory
* Thu Mar 30 2017 meissner@suse.com
- prerequire useradd and groupadd
* Sat Jun 20 2015 dimstar@opensuse.org
- Force GNU inline semantics, fixes build with GCC5.
* Thu Oct 23 2014 nemysis@gmx.ch
- Change descriptions for patches
* Wed Oct 22 2014 nemysis@gmx.ch
- Remove not needed #%%attr
* Wed Oct 22 2014 nemysis@gmx.ch
- Initial package creation
